import { Router } from "express";

import PostController from "../controllers/post";
import auth from '../middlewares/auth';
import multer from 'multer';
import existance from "../middlewares/existance";
import utils from "../middlewares/utils";

const PostRouter = Router();

const upload = multer({
    dest: "./temp",
    limits: {
        fileSize: 12 * 1024 * 1024
    }
});


PostRouter.post('/create', auth.authenticate, upload.single("file"), utils.handlePostData, PostController.create);
PostRouter.put('/update/:postId', auth.authorizeForPost, existance.postShouldExist, upload.single("file"), utils.handlePostData, PostController.update);
PostRouter.delete('/delete/:postId', auth.authorizeForPost, existance.postShouldExist, PostController.delete);

export default PostRouter;